import importlib
import json

import pytest
from pymemri.data.schema import Message
from pymemri.pod.client import PodClient
from pymemri.plugin.pluginbase import get_plugin_cls


@pytest.fixture
def client():
    return PodClient()


@pytest.fixture
def metadata():
    with open("./metadata.json") as f:
        content = json.load(f)
    return content


def create_dummy_data(client: PodClient) -> dict:
    """
    Add dummy data to pod and return the search query that retrieves the data.
    """
    # Add multilinguage Message items to the Pod
    client.add_to_schema(Message)
    client.bulk_action(
        create_items = [Message(content=sample, service="sentiment_test") 
        for sample in ["this is great", "this is awful", "c'est incroyable", "c'est horrible"]]
    )
    
    # Return query parameters to retrieve dummy data
    return {"type": "Message", "service": "sentiment_test"}


@pytest.mark.filterwarnings("ignore:Plugin needs a pluginRun as kwarg")
def test_plugin(client, metadata):
    search_query = create_dummy_data(client)

    # Load plugin
    plugin_cls = get_plugin_cls(metadata["pluginModule"], metadata["pluginName"])
    plugin = plugin_cls(client=client)
    plugin.add_to_schema()

    # Run plugin
    plugin.query = search_query
    plugin.run()

    items = plugin.client.search(plugin.query)
    plugin.predict(items)


    # Check if all data has a prediction
    results = client.search(plugin.query)
    assert len(results)
    assert all([len(result.label)==1 for result in results])
    assert all([result.label[0].value for result in results])
